==> dyte_core-0.2.0.tar.gz: lib/src/dyte_core.dart <==
import 'dart:convert';

import 'package:dyte_core_platform_interface/dyte_core_platform_interface.dart';

DyteClientPlatform get _platform => DyteClientPlatform.instance;

class DyteBase64Encoding {
  static String auth({required String organizationId, required String apiKey}) {
    final decodedString = '${organizationId.trim()}:${apiKey.trim()}';
    final bytes = utf8.encode(decodedString);

    final base64Enc = base64.encode(bytes);
    return 'Basic $base64Enc';
  }
}

class DyteMobileClient {
  void init(DyteMeetingInfo meetingInfo) => _platform.init(meetingInfo);

  void joinRoom() => _platform.joinRoom();

  void leaveRoom() => _platform.leaveRoom();

  DyteRoomParticipants get participants => _platform.participants;

  DytePermissions get permissions => _platform.permissions;

  Stream<List<DyteMeetingParticipant>> get activeStream =>
      _platform.activeStream;

  Stream<DyteRoomParticipants> get participantsStream =>
      _platform.participantsStream.distinct();

  void closeParticipantsStream() => _platform.closeParticipantsStream();

  void addMeetingRoomEventsListener(
          DyteMeetingRoomEventsListener meetingRoomEventsListener) =>
      _platform.addMeetingRoomEventsListener(meetingRoomEventsListener);

  void removeMeetingRoomEventsListener(
          DyteMeetingRoomEventsListener meetingRoomEventsListener) =>
      _platform.removeMeetingRoomEventsListener(meetingRoomEventsListener);

  void addParticipantEventsListener(
          DyteParticipantEventsListener participantEventsListener) =>
      _platform.addParticipantEventListener(participantEventsListener);

  void removeParticipantEventsListener(
          DyteParticipantEventsListener participantEventsListener) =>
      _platform.addParticipantEventListener(participantEventsListener);

  void addSelfEventsListener(DyteSelfEventsListener dyteSelfListener) =>
      _platform.addSelfParticipantEventListener(dyteSelfListener);

  void removeSelfEventsListener(DyteSelfEventsListener dyteSelfListener) =>
      _platform.addSelfParticipantEventListener(dyteSelfListener);

  void addPluginEventsListener(DytePluginEventsListener pluginEventsListener) =>
      _platform.addPluginEventsListener(pluginEventsListener);

  void removePluginEventsListener(
          DytePluginEventsListener pluginEventsListener) =>
      _platform.addPluginEventsListener(pluginEventsListener);

  void addRecordingListener(
          DyteRecordingEventsListener recordingEventsListener) =>
      _platform.addRecordingListener(recordingEventsListener);

  void removeRecordingListener(
          DyteRecordingEventsListener recordingEventsListener) =>
      _platform.removeRecordingListener(recordingEventsListener);

  void addChatEventsListener(DyteChatEventsListener chatEventsListener) =>
      _platform.addChatListener(chatEventsListener);

  void removeChatEventsListener(DyteChatEventsListener chatEventsListener) =>
      _platform.addChatListener(chatEventsListener);

  void addDataEventsListener(DyteDataEventsListener dataEventsListener) =>
      _platform.addDataUpdateListener(dataEventsListener);

  void removeDataEventsListener(DyteDataEventsListener dataEventsListener) =>
      _platform.removeDataEventListener(dataEventsListener);
  void addWaitingRoomListener(
          DyteWaitingRoomEventsListener waitingRoomEventsListener) =>
      _platform.addWaitingRoomListener(waitingRoomEventsListener);

  void removeWaitingRoomListener(
          DyteWaitingRoomEventsListener waitingRoomEventsListener) =>
      _platform.removeWaitingRoomListener(waitingRoomEventsListener);
  void addPollEventsListener(DytePollEventsListener pollEventsListener) =>
      _platform.addPollListener(pollEventsListener);

  void removePollEventsListener(DytePollEventsListener pollEventsListener) =>
      _platform.removePollListener(pollEventsListener);

  void addLivestreamEventsListener(
          DyteLivestreamEventsListener livestreamEventsListener) =>
      _platform.addLivestreamListener(livestreamEventsListener);

  void removeLivestreamEventsListener(
          DyteLivestreamEventsListener livestreamEventsListener) =>
      _platform.removeLivestreamListener(livestreamEventsListener);

  DyteMeta get meta => _platform.meta;

  DyteLocalUser get localUser => _platform.localUser;

  Future<void> setPage(int pageNumber) => _platform.setPage(pageNumber);

  DyteRecording get recording => _platform.recording;

  DyteStageStatus get stageStatus => _platform.stageStatus;

  DytePoll get polls => _platform.polls;

  DyteChat get chat => _platform.chat;

  DytePlugins get plugins => _platform.plugins;

  DyteHostActions get hostActions => _platform.hostActions;

  DyteLivestream get livestream => _platform.livestream;
}

==> dyte_core-0.3.2.tar.gz: lib/src/dyte_core.dart <==
import 'dart:convert';

import 'package:dyte_core_platform_interface/dyte_core_platform_interface.dart';

DyteClientPlatform get _platform => DyteClientPlatform.instance;

class DyteBase64Encoding {
  static String auth({required String organizationId, required String apiKey}) {
    final decodedString = '${organizationId.trim()}:${apiKey.trim()}';
    final bytes = utf8.encode(decodedString);

    final base64Enc = base64.encode(bytes);
    return 'Basic $base64Enc';
  }
}

class DyteMobileClient {
  void init(DyteMeetingInfo meetingInfo) => _platform.init(meetingInfo);

  void joinRoom() => _platform.joinRoom();

  void leaveRoom() => _platform.leaveRoom();

  DyteParticipants get participants => _platform.participants;

  DytePermissions get permissions => _platform.permissions;

  Stream<List<DyteMeetingParticipant>> get activeStream =>
      _platform.activeStream;

  Stream<DyteParticipants> get participantsStream =>
      _platform.participantsStream.distinct();

  void closeParticipantsStream() => _platform.closeParticipantsStream();

  void addMeetingRoomEventsListener(
          DyteMeetingRoomEventsListener meetingRoomEventsListener) =>
      _platform.addMeetingRoomEventsListener(meetingRoomEventsListener);

  void removeMeetingRoomEventsListener(
          DyteMeetingRoomEventsListener meetingRoomEventsListener) =>
      _platform.removeMeetingRoomEventsListener(meetingRoomEventsListener);

  void addParticipantEventsListener(
          DyteParticipantEventsListener participantEventsListener) =>
      _platform.addParticipantEventListener(participantEventsListener);

  void removeParticipantEventsListener(
          DyteParticipantEventsListener participantEventsListener) =>
      _platform.removeParticipantEventListener(participantEventsListener);

  void addSelfEventsListener(DyteSelfEventsListener dyteSelfListener) =>
      _platform.addSelfParticipantEventListener(dyteSelfListener);

  void removeSelfEventsListener(DyteSelfEventsListener dyteSelfListener) =>
      _platform.removeSelfParticipantEventListener(dyteSelfListener);

  void addPluginEventsListener(DytePluginEventsListener pluginEventsListener) =>
      _platform.addPluginEventsListener(pluginEventsListener);

  void removePluginEventsListener(
          DytePluginEventsListener pluginEventsListener) =>
      _platform.removePluginEventsListener(pluginEventsListener);

  void addRecordingListener(
          DyteRecordingEventsListener recordingEventsListener) =>
      _platform.addRecordingListener(recordingEventsListener);

  void removeRecordingListener(
          DyteRecordingEventsListener recordingEventsListener) =>
      _platform.removeRecordingListener(recordingEventsListener);

  void addChatEventsListener(DyteChatEventsListener chatEventsListener) =>
      _platform.addChatListener(chatEventsListener);

  void removeChatEventsListener(DyteChatEventsListener chatEventsListener) =>
      _platform.removeChatListener(chatEventsListener);

  void addDataEventsListener(DyteDataEventsListener dataEventsListener) =>
      _platform.addDataUpdateListener(dataEventsListener);

  void removeDataEventsListener(DyteDataEventsListener dataEventsListener) =>
      _platform.removeDataEventListener(dataEventsListener);
  void addWaitingRoomListener(
          DyteWaitingRoomEventsListener waitingRoomEventsListener) =>
      _platform.addWaitingRoomListener(waitingRoomEventsListener);

  void removeWaitingRoomListener(
          DyteWaitingRoomEventsListener waitingRoomEventsListener) =>
      _platform.removeWaitingRoomListener(waitingRoomEventsListener);
  void addPollEventsListener(DytePollEventsListener pollEventsListener) =>
      _platform.addPollListener(pollEventsListener);

  void removePollEventsListener(DytePollEventsListener pollEventsListener) =>
      _platform.removePollListener(pollEventsListener);

  void addLivestreamEventsListener(
          DyteLivestreamEventsListener livestreamEventsListener) =>
      _platform.addLivestreamListener(livestreamEventsListener);

  void removeLivestreamEventsListener(
          DyteLivestreamEventsListener livestreamEventsListener) =>
      _platform.removeLivestreamListener(livestreamEventsListener);

  void addStageEventsListener(DyteStageEventsListener stageEventsListener) =>
      _platform.addStageEventsListener(stageEventsListener);

  void removeStageEventsListener(DyteStageEventsListener stageEventsListener) =>
      _platform.removeStageEventsListener(stageEventsListener);

  void disableCache() => _platform.disableCache();

  void enableCache() => _platform.enableCache();

  void launchUrl(String url) => _platform.launchUrl(url);

  void broadcastMessage(String type, Map<String, dynamic> payload) =>
      _platform.broadcastMessage(type, payload);

  void release() => _platform.release();

  DyteMeta get meta => _platform.meta;

  DyteSelfUser get localUser => _platform.localUser;

  Future<void> setPage(int pageNumber) => _platform.setPage(pageNumber);

  DyteRecording get recording => _platform.recording;

  DytePoll get polls => _platform.polls;

  DyteChat get chat => _platform.chat;

  DytePlugins get plugins => _platform.plugins;

  DyteHostActions get hostActions => _platform.hostActions;

  DyteLivestream get livestream => _platform.livestream;

  DyteStage get stage => _platform.stage;
}
